@@ -75,7 +75,7 @@ use std::{fmt, io};
 use tokio::fs::File;
 
 use crate::config::{GooseConfiguration, GooseDefaults};
-use crate::controller::{GooseControllerProtocol, GooseControllerRequest};
+use crate::controller::{ControllerProtocol, ControllerRequest};
 use crate::goose::{GaggleUser, GooseUser, GooseUserCommand, Scenario, Transaction};
 use crate::graph::GraphData;
 use crate::logger::{GooseLoggerJoinHandle, GooseLoggerTx};
@@ -167,6 +167,11 @@ pub enum GooseError {
         /// An optional explanation of the error.
         detail: String,
     },
+    /// Invalid controller command.
+    InvalidControllerCommand {
+        /// An optional explanation of the error.
+        detail: String,
+    },
     /// [`GooseAttack`](./struct.GooseAttack.html) has no [`Scenario`](./goose/struct.Scenario.html) defined.
     NoScenarios {
         /// An optional explanation of the error.
@@ -185,6 +190,7 @@ impl GooseError {
             GooseError::InvalidOption { .. } => "invalid option or value specified",
             GooseError::InvalidWaitTime { .. } => "invalid wait_time specified",
             GooseError::InvalidWeight { .. } => "invalid weight specified",
+            GooseError::InvalidControllerCommand { .. } => "invalid controller command",
             GooseError::NoScenarios { .. } => "no scenarios defined",
         }
     }
@@ -327,7 +333,7 @@ struct GooseAttackRunState {
     /// Optional sender for throttle thread, if enabled.
     parent_to_throttle_tx: Option<flume::Sender<bool>>,
     /// Optional channel allowing controller thread to make requests, if not disabled.
-    controller_channel_rx: Option<flume::Receiver<GooseControllerRequest>>,
+    controller_channel_rx: Option<flume::Receiver<ControllerRequest>>,
     /// Optional unbuffered writer for html-formatted report file, if enabled.
     report_file: Option<File>,
     /// A flag tracking whether or not the header has been written when the metrics
@@ -729,7 +735,7 @@ impl GooseAttack {
     }
 
     /// Pre-allocate a vector of weighted [`GooseUser`](./goose/struct.GooseUser.html)s.
-    fn weight_scenario_users(&mut self) -> Result<Vec<GooseUser>, GooseError> {
+    fn weight_scenario_users(&mut self, total_users: usize) -> Result<Vec<GooseUser>, GooseError> {
         trace!("weight_scenario_users");
 
         let weighted_scenarios = self.allocate_scenarios();
@@ -760,7 +766,7 @@ impl GooseAttack {
                     self.metrics.hash,
                 )?);
                 user_count += 1;
-                if user_count == self.test_plan.total_users() {
+                if user_count == total_users {
                     debug!("created {} weighted_users", user_count);
                     return Ok(weighted_users);
                 }
@@ -1045,7 +1051,7 @@ impl GooseAttack {
 
             if self.attack_mode == AttackMode::StandAlone {
                 // Allocate a state for each of the users we are about to start.
-                self.weighted_users = self.weight_scenario_users()?;
+                self.weighted_users = self.weight_scenario_users(self.test_plan.total_users())?;
             } else if self.attack_mode == AttackMode::Manager {
                 // Build a list of users to be allocated on Workers.
                 self.weighted_gaggle_users = self.prepare_worker_scenario_users()?;
@@ -1117,7 +1123,7 @@ impl GooseAttack {
     // threads share a control channel, allowing it to send requests to the parent process. When
     // a response is required, the Controller will also send a one-shot channel allowing a direct
     // reply.
-    async fn setup_controllers(&mut self) -> Option<flume::Receiver<GooseControllerRequest>> {
+    async fn setup_controllers(&mut self) -> Option<flume::Receiver<ControllerRequest>> {
         // If the telnet controller is disabled, return immediately.
         if self.configuration.no_telnet && self.configuration.no_websocket {
             return None;
@@ -1126,8 +1132,8 @@ impl GooseAttack {
         // Create an unbounded channel for controller threads to send requests to the parent
         // process.
         let (all_threads_controller_request_tx, controller_request_rx): (
-            flume::Sender<GooseControllerRequest>,
-            flume::Receiver<GooseControllerRequest>,
+            flume::Sender<ControllerRequest>,
+            flume::Receiver<ControllerRequest>,
         ) = flume::unbounded();
 
         // Configured telnet Controller if not disabled.
@@ -1156,7 +1162,7 @@ impl GooseAttack {
             let _ = Some(tokio::spawn(controller::controller_main(
                 self.configuration.clone(),
                 all_threads_controller_request_tx.clone(),
-                GooseControllerProtocol::Telnet,
+                ControllerProtocol::Telnet,
             )));
         }
 
@@ -1187,7 +1193,7 @@ impl GooseAttack {
             let _ = Some(tokio::spawn(controller::controller_main(
                 self.configuration.clone(),
                 all_threads_controller_request_tx,
-                GooseControllerProtocol::WebSocket,
+                ControllerProtocol::WebSocket,
             )));
         }
 
@@ -1321,7 +1327,8 @@ impl GooseAttack {
         } else if let Some(started) = self.started {
             started.elapsed().as_millis()
         } else {
-            unreachable!("the load test had to have started");
+            // An idle load test.
+            0
         }
     }
 
@@ -1554,7 +1561,7 @@ impl GooseAttack {
         // If this is the last step of the load test and there are 0 users, shut down.
         if goose_attack_run_state.active_users == 0
             // Subtract 1 from len() as it starts at 1 while current starts at 0.
-            && self.test_plan.current == self.test_plan.steps.len() - 1
+            && self.test_plan.current >= self.test_plan.steps.len() - 1
         {
             // Load test is shutting down, update pipe handler so there is no panic
             // when the Manager goes away.
