@@ -9,7 +9,7 @@ use std::time;
 
 use crate::metrics::{
     self, GooseErrorMetricAggregate, GooseErrorMetrics, GooseRequestMetricAggregate,
-    GooseRequestMetrics, GooseTaskMetricAggregate, GooseTaskMetrics,
+    GooseRequestMetrics, TransactionMetricAggregate, TransactionMetrics,
 };
 use crate::util;
 use crate::worker::GaggleMetrics;
@@ -21,14 +21,12 @@ const GRACEFUL_SHUTDOWN_TIMEOUT: usize = 30;
 /// All elements required to initialize a user in a worker process.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct GooseUserInitializer {
-    /// An index into the internal `GooseTest.task_sets` vector, indicating which GooseTaskSet is running.
-    pub task_sets_index: usize,
+    /// An index into the internal `GooseTest.scenarios` vector, indicating which Scenario is running.
+    pub scenarios_index: usize,
     /// The base_url for this user thread.
     pub base_url: String,
     /// A local copy of the global GooseConfiguration.
     pub config: GooseConfiguration,
-    /// How long the load test should run, in seconds.
-    pub run_time: usize,
     /// Numerical identifier for worker.
     pub worker_id: usize,
 }
@@ -69,35 +67,38 @@ fn pipe_closed(_pipe: Pipe, event: PipeEvent) {
     }
 }
 
-/// Merge per-user task metrics from user thread into global parent metrics
-fn merge_tasks_from_worker(
-    parent_task: &GooseTaskMetricAggregate,
-    user_task: &GooseTaskMetricAggregate,
-) -> GooseTaskMetricAggregate {
+/// Merge per-user transaction metrics from user thread into global parent metrics
+fn merge_transactions_from_worker(
+    parent_transaction: &TransactionMetricAggregate,
+    user_transaction: &TransactionMetricAggregate,
+) -> TransactionMetricAggregate {
     // Make a mutable copy where we can merge things
-    let mut merged_task = parent_task.clone();
+    let mut merged_transaction = parent_transaction.clone();
     // Iterate over user times, and merge into global time
-    merged_task.times = metrics::merge_times(merged_task.times, user_task.times.clone());
-    // Increment total task time counter.
-    merged_task.total_time += &user_task.total_time;
-    // Increment count of how many task counters we've seen.
-    merged_task.counter += &user_task.counter;
-    // If user had new fastest task time, update global fastest task time.
-    merged_task.min_time = metrics::update_min_time(merged_task.min_time, user_task.min_time);
-    // If user had new slowest task time, update global slowest task time.
-    merged_task.max_time = metrics::update_max_time(merged_task.max_time, user_task.max_time);
+    merged_transaction.times =
+        metrics::merge_times(merged_transaction.times, user_transaction.times.clone());
+    // Increment total transaction time counter.
+    merged_transaction.total_time += &user_transaction.total_time;
+    // Increment count of how many transaction counters we've seen.
+    merged_transaction.counter += &user_transaction.counter;
+    // If user had new fastest transaction time, update global fastest transaction time.
+    merged_transaction.min_time =
+        metrics::update_min_time(merged_transaction.min_time, user_transaction.min_time);
+    // If user had new slowest transaction time, update global slowest transaction time.
+    merged_transaction.max_time =
+        metrics::update_max_time(merged_transaction.max_time, user_transaction.max_time);
     // Increment total success counter.
-    merged_task.success_count += &user_task.success_count;
+    merged_transaction.success_count += &user_transaction.success_count;
     // Increment total fail counter.
-    merged_task.fail_count += &user_task.fail_count;
-    merged_task
+    merged_transaction.fail_count += &user_transaction.fail_count;
+    merged_transaction
 }
 
 /// Merge per-user request metrics from user thread into global parent metrics
 fn merge_requests_from_worker(
     parent_request: &GooseRequestMetricAggregate,
     user_request: &GooseRequestMetricAggregate,
-    status_codes: bool,
+    no_status_codes: bool,
 ) -> GooseRequestMetricAggregate {
     // Make a mutable copy where we can merge things
     let mut merged_request = parent_request.clone();
@@ -125,19 +126,18 @@ fn merge_requests_from_worker(
     // Increment total fail counter.
     merged_request.fail_count += &user_request.fail_count;
     // Only accrue overhead of merging status_code_counts if we're going to display the results
-    if status_codes {
+    if !no_status_codes {
         for (status_code, count) in &user_request.status_code_counts {
-            let new_count;
             // Add user count into global count
-            if let Some(existing_status_code_count) =
+            let new_count = if let Some(existing_status_code_count) =
                 merged_request.status_code_counts.get(status_code)
             {
-                new_count = *existing_status_code_count + *count;
+                *existing_status_code_count + *count
             }
             // No global count exists yet, so start with user count
             else {
-                new_count = *count;
-            }
+                *count
+            };
             merged_request
                 .status_code_counts
                 .insert(*status_code, new_count);
@@ -193,17 +193,17 @@ fn merge_request_metrics(goose_attack: &mut GooseAttack, requests: GooseRequestM
         debug!("requests metrics received: {:?}", requests.len());
         for (request_key, request) in requests {
             trace!("request_key: {}", request_key);
-            let merged_request;
-            if let Some(parent_request) = goose_attack.metrics.requests.get(&request_key) {
-                merged_request = merge_requests_from_worker(
-                    parent_request,
-                    &request,
-                    goose_attack.configuration.status_codes,
-                );
-            } else {
-                // First time seeing this request, simply insert it.
-                merged_request = request.clone();
-            }
+            let merged_request =
+                if let Some(parent_request) = goose_attack.metrics.requests.get(&request_key) {
+                    merge_requests_from_worker(
+                        parent_request,
+                        &request,
+                        goose_attack.configuration.no_status_codes,
+                    )
+                } else {
+                    // First time seeing this request, simply insert it.
+                    request.clone()
+                };
             goose_attack
                 .metrics
                 .requests
@@ -212,15 +212,17 @@ fn merge_request_metrics(goose_attack: &mut GooseAttack, requests: GooseRequestM
     }
 }
 
-/// Helper to merge in task metrics from Worker.
-fn merge_task_metrics(goose_attack: &mut GooseAttack, tasks: GooseTaskMetrics) {
-    for task_set in tasks {
-        for task in task_set {
-            let merged_task = merge_tasks_from_worker(
-                &goose_attack.metrics.tasks[task.taskset_index][task.task_index],
-                &task,
+/// Helper to merge in transaction metrics from Worker.
+fn merge_transaction_metrics(goose_attack: &mut GooseAttack, transactions: TransactionMetrics) {
+    for scenario in transactions {
+        for transaction in scenario {
+            let merged_transaction = merge_transactions_from_worker(
+                &goose_attack.metrics.transactions[transaction.scenario_index]
+                    [transaction.transaction_index],
+                &transaction,
             );
-            goose_attack.metrics.tasks[task.taskset_index][task.task_index] = merged_task;
+            goose_attack.metrics.transactions[transaction.scenario_index]
+                [transaction.transaction_index] = merged_transaction;
         }
     }
 }
@@ -231,13 +233,13 @@ fn merge_error_metrics(goose_attack: &mut GooseAttack, errors: GooseErrorMetrics
         debug!("errors received: {:?}", errors.len());
         for (error_key, error) in errors {
             trace!("error_key: {}", error_key);
-            let merged_error;
-            if let Some(parent_error) = goose_attack.metrics.errors.get(&error_key) {
-                merged_error = merge_errors_from_worker(parent_error, &error);
-            } else {
-                // First time seeing this error, simply insert it.
-                merged_error = error.clone();
-            }
+            let merged_error =
+                if let Some(parent_error) = goose_attack.metrics.errors.get(&error_key) {
+                    merge_errors_from_worker(parent_error, &error)
+                } else {
+                    // First time seeing this error, simply insert it.
+                    error.clone()
+                };
             goose_attack
                 .metrics
                 .errors
@@ -289,8 +291,7 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
     let mut workers: HashSet<Pipe> = HashSet::new();
 
     // Track start time, we'll reset this when the test actually starts.
-    let mut started = time::Instant::now();
-    goose_attack.started = Some(started);
+    goose_attack.started = Some(time::Instant::now());
     let mut running_metrics_timer = time::Instant::now();
     let mut exit_timer = time::Instant::now();
     let mut load_test_running = false;
@@ -300,24 +301,31 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
     let canceled = Arc::new(AtomicBool::new(false));
     util::setup_ctrlc_handler(&canceled);
 
-    // Initialize the optional task metrics.
+    // Initialize the optional transaction metrics.
     goose_attack
         .metrics
-        .initialize_task_metrics(
-            &goose_attack.task_sets,
+        .initialize_transaction_metrics(
+            &goose_attack.scenarios,
             &goose_attack.configuration,
             &goose_attack.defaults,
         )
-        .expect("failed to initialize task metrics");
+        .expect("failed to initialize transaction metrics");
 
     // Update metrics, which doesn't happen automatically on the Master as we don't
     // invoke start_attack. Hatch rate is required here so unwrap() is safe.
-    let hatch_rate = util::get_hatch_rate(goose_attack.configuration.hatch_rate.clone());
-    let maximum_hatched = hatch_rate * goose_attack.run_time as f32;
+    // Divide the number of new users to launch by the time configured to launch them.
+    let hatch_rate: f32 = (goose_attack.test_plan.steps[0].0)
+        as f32
+        / goose_attack.test_plan.steps[0].1 as f32
+        // Convert from milliseconds to seconds.
+        * 1_000.0;
+    let maximum_hatched = hatch_rate * goose_attack.test_plan.steps[1].1 as f32;
     if maximum_hatched < goose_attack.configuration.users.unwrap() as f32 {
-        goose_attack.metrics.users = maximum_hatched as usize;
+        goose_attack.metrics.maximum_users = maximum_hatched as usize;
+        goose_attack.metrics.total_users = maximum_hatched as usize;
     } else {
-        goose_attack.metrics.users = goose_attack.configuration.users.unwrap();
+        goose_attack.metrics.maximum_users = goose_attack.configuration.users.unwrap();
+        goose_attack.metrics.total_users = goose_attack.configuration.users.unwrap();
     }
 
     // Worker control loop.
@@ -330,7 +338,7 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                 if load_test_running {
                     info!(
                         "worker went away, stopping gracefully after {} seconds...",
-                        started.elapsed().as_secs()
+                        goose_attack.started.unwrap().elapsed().as_secs()
                     );
                     load_test_finished = true;
                     exit_timer = time::Instant::now();
@@ -345,10 +353,15 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
         if load_test_running {
             if !load_test_finished {
                 // Test ran to completion or was canceled with ctrl-c.
-                if util::timer_expired(started, goose_attack.run_time)
-                    || canceled.load(Ordering::SeqCst)
+                if util::ms_timer_expired(
+                    goose_attack.started.unwrap(),
+                    goose_attack.test_plan.steps[1].1,
+                ) || canceled.load(Ordering::SeqCst)
                 {
-                    info!("stopping after {} seconds...", started.elapsed().as_secs());
+                    info!(
+                        "stopping after {} seconds...",
+                        goose_attack.started.unwrap().elapsed().as_secs()
+                    );
                     goose_attack.metrics.duration =
                         goose_attack.started.unwrap().elapsed().as_secs() as usize;
                     load_test_finished = true;
@@ -468,10 +481,9 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                             };
                             // Build a vector of GooseUser initializers for next worker.
                             users.push(GooseUserInitializer {
-                                task_sets_index: user.task_sets_index,
+                                scenarios_index: user.scenarios_index,
                                 base_url: user.base_url.read().await.to_string(),
                                 config: user.config.clone(),
-                                run_time: goose_attack.run_time,
                                 worker_id: workers.len(),
                             });
                         }
@@ -502,8 +514,7 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                         {
                             info!("gaggle distributed load test started");
                             // Reset start time, the distributed load test is truly starting now.
-                            started = time::Instant::now();
-                            goose_attack.started = Some(started);
+                            goose_attack.started = Some(time::Instant::now());
                             running_metrics_timer = time::Instant::now();
                             load_test_running = true;
 
@@ -537,9 +548,9 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
                             GaggleMetrics::Requests(requests) => {
                                 merge_request_metrics(&mut goose_attack, requests)
                             }
-                            // Merge in task metrics from Worker.
-                            GaggleMetrics::Tasks(tasks) => {
-                                merge_task_metrics(&mut goose_attack, tasks)
+                            // Merge in transaction metrics from Worker.
+                            GaggleMetrics::Transactions(transactions) => {
+                                merge_transaction_metrics(&mut goose_attack, transactions)
                             }
                             // Merge in error metrics from Worker.
                             GaggleMetrics::Errors(errors) => {
