@@ -9,8 +9,8 @@
 
 pub use crate::config::{GooseDefault, GooseDefaultType};
 pub use crate::goose::{
-    GooseMethod, GooseRequest, GooseTask, GooseTaskError, GooseTaskFunction, GooseTaskResult,
-    GooseTaskSet, GooseUser,
+    GooseMethod, GooseRequest, GooseUser, Scenario, Transaction, TransactionError,
+    TransactionFunction, TransactionResult,
 };
 pub use crate::metrics::{GooseCoordinatedOmissionMitigation, GooseMetrics};
-pub use crate::{task, taskset, GooseAttack, GooseError, GooseScheduler};
+pub use crate::{scenario, transaction, GooseAttack, GooseError, GooseScheduler};
