@@ -7,7 +7,7 @@ use tokio_tungstenite::tungstenite::Message;
 
 use goose::config::GooseConfiguration;
 use goose::controller::{
-    GooseControllerCommand, GooseControllerWebSocketRequest, GooseControllerWebSocketResponse,
+    ControllerCommand, ControllerWebSocketRequest, ControllerWebSocketResponse,
 };
 use goose::prelude::*;
 
@@ -21,9 +21,12 @@ const ABOUT_PATH: &str = "/about.html";
 const INDEX_KEY: usize = 0;
 const ABOUT_KEY: usize = 1;
 
-const USERS: usize = 5;
-const HATCH_RATE: usize = 10;
+const START_USERS: usize = 5;
+const MAX_USERS: usize = 20;
+const FINAL_USERS: usize = 10;
+const HATCH_RATE: usize = 25;
 const RUN_TIME: usize = 10;
+const STARTUP_TIME: usize = 1;
 
 // There are multiple test variations in this file.
 #[derive(Clone)]
@@ -38,12 +41,12 @@ enum TestType {
 struct TestState {
     // A buffer for the telnet Controller.
     buf: [u8; 2048],
-    // Track iterations through GooseControllerCommands.
+    // Track iterations through ControllerCommands.
     position: usize,
     // Track the steps within a given iteration.
     step: usize,
     // The Controller command currently being tested.
-    command: GooseControllerCommand,
+    command: ControllerCommand,
     // A TCP socket if testing the telnet Controller.
     telnet_stream: Option<TcpStream>,
     // A TCP socket if testing the WebSocket Controller.
@@ -138,13 +141,19 @@ fn validate_one_scenario(
     assert!(about_metrics.fail_count == 0);
 
     // Users were correctly configured through the controller.
-    assert!(goose_metrics.total_users == USERS);
+    assert!(goose_metrics.total_users == MAX_USERS);
 
     // Host was not configured at start time.
     assert!(configuration.host.is_empty());
 
     // The load test was manually shut down instead of running to completion.
     assert!(goose_metrics.duration < RUN_TIME);
+
+    // Increasing, Maintaining, Increasing, Maintaining, Decreasing, Maintaining, Canceling,
+    // Finished, Finished.
+    // Finished is logged twice because `stop` puts the test to Idle, and then `shutdown`
+    // actually shuts down the test, and both are logged as "Finished".
+    assert!(goose_metrics.history.len() == 9);
 }
 
 // Returns the appropriate scenario needed to build these tests.
@@ -184,7 +193,7 @@ async fn run_standalone_test(test_type: TestType) {
         loop {
             // Process data received from the client in a loop.
             let response;
-            let websocket_response: GooseControllerWebSocketResponse;
+            let websocket_response: ControllerWebSocketResponse;
             if let Some(stream) = test_state.telnet_stream.as_mut() {
                 let _ = match stream.read(&mut test_state.buf) {
                     Ok(data) => data,
@@ -224,7 +233,7 @@ async fn run_standalone_test(test_type: TestType) {
 
             //println!("{:?}: {}", test_state.command, response);
             match test_state.command {
-                GooseControllerCommand::Exit => {
+                ControllerCommand::Exit => {
                     match test_state.step {
                         // Exit the Controller.
                         0 => {
@@ -242,7 +251,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Help => {
+                ControllerCommand::Help => {
                     match test_state.step {
                         0 => {
                             // Request the help text.
@@ -264,7 +273,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Host => {
+                ControllerCommand::Host => {
                     match test_state.step {
                         // Set the host to be load tested.
                         0 => {
@@ -288,20 +297,42 @@ async fn run_standalone_test(test_type: TestType) {
                         // Confirm that we can't configure an invalid host that does
                         // match the regex.
                         _ => {
-                            assert!(response.starts_with("unrecognized command"));
+                            assert!(response.starts_with("failed to reconfigure host"));
 
                             // Move onto the next command.
                             test_state = update_state(Some(test_state), &test_type);
                         }
                     }
                 }
-                GooseControllerCommand::Users => {
+                ControllerCommand::TestPlan => {
+                    match test_state.step {
+                        // Try and set an invalid testplan.
+                        0 => {
+                            make_request(&mut test_state, "testplan 10\r\n");
+                        }
+                        1 => {
+                            // Confirm that an invalid testplan fails.
+                            assert!(response.starts_with("unrecognized command"));
+
+                            // Set a valid test plan.
+                            make_request(&mut test_state, "test_plan 10,2s;10,30m5s;0,1h2s\r\n");
+                        }
+                        _ => {
+                            // Confirm that an invalid testplan fails.
+                            assert!(response.starts_with("test-plan configured"));
+
+                            // Move onto the next command.
+                            test_state = update_state(Some(test_state), &test_type);
+                        }
+                    }
+                }
+                ControllerCommand::Users => {
                     match test_state.step {
                         // Reconfigure the number of users simulated by the load test.
                         0 => {
                             make_request(
                                 &mut test_state,
-                                &["users ", &USERS.to_string(), "\r\n"].concat(),
+                                &["users ", &START_USERS.to_string(), "\r\n"].concat(),
                             );
                         }
                         // Confirm that the users are reconfigured.
@@ -322,7 +353,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::HatchRate => {
+                ControllerCommand::HatchRate => {
                     match test_state.step {
                         // Configure a decimal hatch_rate.
                         0 => {
@@ -364,7 +395,46 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::RunTime => {
+                ControllerCommand::StartupTime => {
+                    match test_state.step {
+                        // Try to configure a decimal StartupTime.
+                        0 => {
+                            make_request(&mut test_state, "startup-time .1\r\n");
+                        }
+                        // Configure a StartupTime with hms notation.
+                        1 => {
+                            assert!(response.starts_with("unrecognized command"));
+
+                            make_request(&mut test_state, "startup-time 1h2m3s\r\n");
+                        }
+                        // Configure a proper StartupTime.
+                        2 => {
+                            assert!(response.starts_with("startup_time configured"));
+
+                            make_request(
+                                &mut test_state,
+                                &["startup_time ", &STARTUP_TIME.to_string(), "\r\n"].concat(),
+                            );
+                        }
+                        // Restore the HatchRate.
+                        3 => {
+                            assert!(response.starts_with("startup_time configured"));
+
+                            // Configure hatch_rate with a single integer.
+                            make_request(
+                                &mut test_state,
+                                &["hatchrate ", &HATCH_RATE.to_string(), "\r\n"].concat(),
+                            );
+                        }
+                        // Confirm hatch_rate is configured.
+                        _ => {
+                            assert!(response.starts_with("hatch_rate configured"));
+
+                            test_state = update_state(Some(test_state), &test_type);
+                        }
+                    }
+                }
+                ControllerCommand::RunTime => {
                     match test_state.step {
                         // Configure run_time using h:m:s format.
                         0 => {
@@ -422,7 +492,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Config => {
+                ControllerCommand::Config => {
                     match test_state.step {
                         // Request the configuration.
                         0 => {
@@ -443,7 +513,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::ConfigJson => {
+                ControllerCommand::ConfigJson => {
                     match test_state.step {
                         // Request the configuration in json format.
                         0 => {
@@ -459,7 +529,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Metrics => {
+                ControllerCommand::Metrics => {
                     match test_state.step {
                         // Request the running metrics.
                         0 => {
@@ -480,7 +550,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::MetricsJson => {
+                ControllerCommand::MetricsJson => {
                     match test_state.step {
                         // Request the running metrics in json format.
                         0 => {
@@ -495,7 +565,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Start => {
+                ControllerCommand::Start => {
                     match test_state.step {
                         // Try to stop an idle load test.
                         0 => {
@@ -524,23 +594,40 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Stop => {
+                ControllerCommand::Stop => {
                     match test_state.step {
-                        // Try to configure users on a running load test.
+                        // Try to configure host on a running load test.
                         0 => {
-                            make_request(&mut test_state, "users 1\r\n");
-                        }
-                        // Confirm users can not be configured on a running load test.
-                        1 => {
-                            assert!(response.starts_with("load test not idle"));
-
-                            // Try to configure host on a running load test.
                             make_request(&mut test_state, "host http://localhost/\r\n");
                         }
-                        // Confirm host can not be configured on a running load test.
-                        2 => {
+                        // Setting host fails, then reconfigure the number of users, increasing.
+                        1 => {
                             assert!(response.starts_with("failed to reconfigure host"));
 
+                            make_request(
+                                &mut test_state,
+                                &["users ", &MAX_USERS.to_string(), "\r\n"].concat(),
+                            );
+                        }
+                        // Setting users succeeds, reconfigure the number of users, decreasing.
+                        2 => {
+                            assert!(response.starts_with("users configured"));
+
+                            // Give Goose a second to increase users.
+                            tokio::time::sleep(time::Duration::from_secs(1)).await;
+
+                            make_request(
+                                &mut test_state,
+                                &["users ", &FINAL_USERS.to_string(), "\r\n"].concat(),
+                            );
+                        }
+                        // Confirm host can not be configured on a running load test.
+                        3 => {
+                            assert!(response.starts_with("users configured"));
+
+                            // Give Goose a second to decrease users.
+                            tokio::time::sleep(time::Duration::from_secs(1)).await;
+
                             // Try to stop a running load test.
                             make_request(&mut test_state, "stop\r\n");
                         }
@@ -556,7 +643,7 @@ async fn run_standalone_test(test_type: TestType) {
                         }
                     }
                 }
-                GooseControllerCommand::Shutdown => {
+                ControllerCommand::Shutdown => {
                     match test_state.step {
                         // Shut down the load test.
                         0 => {
@@ -601,19 +688,21 @@ async fn run_standalone_test(test_type: TestType) {
 fn update_state(test_state: Option<TestState>, test_type: &TestType) -> TestState {
     // The commands being tested, and the order they are tested.
     let commands_to_test = [
-        GooseControllerCommand::Exit,
-        GooseControllerCommand::Help,
-        GooseControllerCommand::Host,
-        GooseControllerCommand::Users,
-        GooseControllerCommand::HatchRate,
-        GooseControllerCommand::RunTime,
-        GooseControllerCommand::Start,
-        GooseControllerCommand::Config,
-        GooseControllerCommand::ConfigJson,
-        GooseControllerCommand::Metrics,
-        GooseControllerCommand::MetricsJson,
-        GooseControllerCommand::Stop,
-        GooseControllerCommand::Shutdown,
+        ControllerCommand::Exit,
+        ControllerCommand::Help,
+        ControllerCommand::Host,
+        ControllerCommand::TestPlan,
+        ControllerCommand::Users,
+        ControllerCommand::HatchRate,
+        ControllerCommand::StartupTime,
+        ControllerCommand::RunTime,
+        ControllerCommand::Start,
+        ControllerCommand::Config,
+        ControllerCommand::ConfigJson,
+        ControllerCommand::Metrics,
+        ControllerCommand::MetricsJson,
+        ControllerCommand::Stop,
+        ControllerCommand::Shutdown,
     ];
 
     if let Some(mut state) = test_state {
@@ -675,7 +764,7 @@ fn make_request(test_state: &mut TestState, command: &str) {
     } else if let Some(stream) = test_state.websocket_stream.as_mut() {
         stream
             .write_message(Message::Text(
-                serde_json::to_string(&GooseControllerWebSocketRequest {
+                serde_json::to_string(&ControllerWebSocketRequest {
                     request: command.to_string(),
                 })
                 .unwrap(),
